manrododex package
==================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   manrododex.CLI

Submodules
----------

manrododex.apiadapter module
----------------------------

.. automodule:: manrododex.apiadapter
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.downloader module
----------------------------

.. automodule:: manrododex.downloader
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.exceptions module
----------------------------

.. automodule:: manrododex.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.logger module
------------------------

.. automodule:: manrododex.logger
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.main module
----------------------

.. automodule:: manrododex.main
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.manga module
-----------------------

.. automodule:: manrododex.manga
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.manga\_helpers module
--------------------------------

.. automodule:: manrododex.manga_helpers
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.mangadex\_lang\_codes module
---------------------------------------

.. automodule:: manrododex.mangadex_lang_codes
   :members:
   :undoc-members:
   :show-inheritance:

manrododex.system\_helper module
--------------------------------

.. automodule:: manrododex.system_helper
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: manrododex
   :members:
   :undoc-members:
   :show-inheritance:
